@@ -18,17 +18,20 @@ import functools
 from email.utils import formatdate
 from hashlib import sha1, sha256
 import hmac
-from io import BytesIO
 import logging
 from operator import itemgetter
 import time
 
-from ibm_botocore.compat import(
+from ibm_botocore.compat import (
     encodebytes, ensure_unicode, HTTPHeaders, json, parse_qs, quote,
-    six, unquote, urlsplit, urlunsplit, HAS_CRT, MD5_AVAILABLE
+    six, unquote, urlsplit, urlunsplit, HAS_CRT
 )
 from ibm_botocore.exceptions import NoCredentialsError
-from ibm_botocore.utils import normalize_url_path, percent_encode_sequence
+from ibm_botocore.utils import is_valid_ipv6_endpoint_url, normalize_url_path, percent_encode_sequence
+
+# Imports for backwards compatibility
+from ibm_botocore.compat import MD5_AVAILABLE # noqa
+
 
 logger = logging.getLogger(__name__)
 
@@ -47,6 +50,7 @@ SIGNED_HEADERS_BLACKLIST = [
     'x-amzn-trace-id',
 ]
 UNSIGNED_PAYLOAD = 'UNSIGNED-PAYLOAD'
+STREAMING_UNSIGNED_PAYLOAD_TRAILER = 'STREAMING-UNSIGNED-PAYLOAD-TRAILER'
 
 
 def _host_from_url(url):
@@ -56,6 +60,9 @@ def _host_from_url(url):
     # 3) excludes userinfo
     url_parts = urlsplit(url)
     host = url_parts.hostname  # urlsplit's hostname is always lowercase
+    # IBM Unsupported
+    # if is_valid_ipv6_endpoint_url(url):
+    #     host = '[%s]' % (host)
     default_ports = {
         'http': 80,
         'https': 443
@@ -113,8 +120,9 @@ class SigV2Auth(BaseSigner):
             if key == 'Signature':
                 continue
             value = six.text_type(params[key])
-            pairs.append(quote(key.encode('utf-8'), safe='') + '=' +
-                         quote(value.encode('utf-8'), safe='-_~'))
+            quoted_key = quote(key.encode('utf-8'), safe='')
+            quoted_value = quote(value.encode('utf-8'), safe='-_~')
+            pairs.append(f'{quoted_key}={quoted_value}')
         qs = '&'.join(pairs)
         string_to_sign += qs
         logger.debug('String to sign: %s', string_to_sign)
@@ -275,12 +283,20 @@ class SigV4Auth(BaseSigner):
         return ' '.join(value.split())
 
     def signed_headers(self, headers_to_sign):
-        l = ['%s' % n.lower().strip() for n in set(headers_to_sign)]
-        l = sorted(l)
-        return ';'.join(l)
+        headers = sorted(
+            [n.lower().strip() for n in set(headers_to_sign)]
+        )
+        return ';'.join(headers)
+
+    def _is_streaming_checksum_payload(self, request):
+        checksum_context = request.context.get('checksum', {})
+        algorithm = checksum_context.get('request_algorithm')
+        return isinstance(algorithm, dict) and algorithm.get('in') == 'trailer'
 
     def payload(self, request):
-        if not self._should_sha256_sign_payload(request):
+        if self._is_streaming_checksum_payload(request):
+            return STREAMING_UNSIGNED_PAYLOAD_TRAILER
+        elif not self._should_sha256_sign_payload(request):
             # When payload signing is disabled, we use this static string in
             # place of the payload checksum.
             return UNSIGNED_PAYLOAD
@@ -387,11 +403,11 @@ class SigV4Auth(BaseSigner):
         self._inject_signature_to_request(request, signature)
 
     def _inject_signature_to_request(self, request, signature):
-        l = ['AWS4-HMAC-SHA256 Credential=%s' % self.scope(request)]
+        auth_str = ['AWS4-HMAC-SHA256 Credential=%s' % self.scope(request)]
         headers_to_sign = self.headers_to_sign(request)
-        l.append('SignedHeaders=%s' % self.signed_headers(headers_to_sign))
-        l.append('Signature=%s' % signature)
-        request.headers['Authorization'] = ', '.join(l)
+        auth_str.append('SignedHeaders=%s' % self.signed_headers(headers_to_sign))
+        auth_str.append('Signature=%s' % signature)
+        request.headers['Authorization'] = ', '.join(auth_str)
         return request
 
     def _modify_request_before_signing(self, request):
@@ -456,8 +472,14 @@ class S3SigV4Auth(SigV4Auth):
         # to implicitly disable body signing. The combination of TLS and
         # content-md5 is sufficiently secure and durable for us to be
         # confident in the request without body signing.
+        
+        checksum_header = 'Content-MD5'
+        checksum_context = request.context.get('checksum', {})
+        algorithm = checksum_context.get('request_algorithm')
+        if isinstance(algorithm, dict) and algorithm.get('in') == 'header':
+            checksum_header = algorithm['name']
         if not request.url.startswith('https') or \
-                'Content-MD5' not in request.headers:
+                checksum_header not in request.headers:
             return True
 
         # If the input is streaming we disable body signing by default.
@@ -515,6 +537,9 @@ class SigV4QueryAuth(SigV4Auth):
         query_dict = dict(
             [(k, v[0]) for k, v in
              parse_qs(url_parts.query, keep_blank_values=True).items()])
+        if request.params:
+            query_dict.update(request.params)
+            request.params = {}
         # The spec is particular about this.  It *has* to be:
         # https://<endpoint>?<operation params>&<auth params>
         # You can't mix the two types of params together, i.e just keep doing
