@@ -11,11 +11,8 @@
 # distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
-import io
-import sys
 import logging
 import functools
-import socket
 
 import urllib3.util
 from urllib3.connection import VerifiedHTTPSConnection
@@ -25,8 +22,10 @@ from urllib3.connectionpool import HTTPSConnectionPool
 
 import ibm_botocore.utils
 from ibm_botocore.compat import six
-from ibm_botocore.compat import HTTPHeaders, HTTPResponse, urlunsplit, urlsplit, \
-     urlencode, MutableMapping
+from ibm_botocore.compat import (
+    HTTPHeaders, HTTPResponse, urlunsplit, urlsplit,
+    urlencode, urlparse, MutableMapping
+)
 from ibm_botocore.exceptions import UnseekableStreamError
 
 
@@ -207,8 +206,10 @@ class AWSConnection(object):
         parts = maybe_status_line.split(None, 2)
         # Check for HTTP/<version> 100 Continue\r\n
         return (
-            len(parts) >= 3 and parts[0].startswith(b'HTTP/') and
-            parts[1] == b'100')
+            len(parts) >= 3
+            and parts[0].startswith(b'HTTP/')
+            and parts[1] == b'100'
+        )
 
 
 class AWSHTTPConnection(AWSConnection, HTTPConnection):
@@ -347,8 +348,10 @@ class AWSRequestPreparer(object):
     def _prepare_url(self, original):
         url = original.url
         if original.params:
+            url_parts = urlparse(url)
+            delim = '&' if url_parts.query else '?'
             params = urlencode(list(original.params.items()), doseq=True)
-            url = '%s?%s' % (url, params)
+            url = delim.join((url, params))
         return url
 
     def _prepare_headers(self, original, prepared_body=None):
@@ -393,32 +396,7 @@ class AWSRequestPreparer(object):
         return body
 
     def _determine_content_length(self, body):
-        # No body, content length of 0
-        if not body:
-            return 0
-
-        # Try asking the body for it's length
-        try:
-            return len(body)
-        except (AttributeError, TypeError) as e:
-            pass
-
-        # Try getting the length from a seekable stream
-        if hasattr(body, 'seek') and hasattr(body, 'tell'):
-            try:
-                orig_pos = body.tell()
-                body.seek(0, 2)
-                end_file_pos = body.tell()
-                body.seek(orig_pos)
-                return end_file_pos - orig_pos
-            except io.UnsupportedOperation:
-                # in case when body is, for example, io.BufferedIOBase object
-                # it has "seek" method which throws "UnsupportedOperation"
-                # exception in such case we want to fall back to "chunked"
-                # encoding
-                pass
-        # Failed to determine the length
-        return None
+        return ibm_botocore.utils.determine_content_length(body)
 
 
 class AWSRequest(object):
