@@ -384,8 +384,10 @@ class ServiceModel(object):
     def endpoint_discovery_required(self):
         for operation in self.operation_names:
             model = self.operation_model(operation)
-            if (model.endpoint_discovery is not None and
-                    model.endpoint_discovery.get('required')):
+            if (
+                model.endpoint_discovery is not None
+                and model.endpoint_discovery.get('required')
+            ):
                 return True
         return False
 
@@ -415,7 +417,6 @@ class ServiceModel(object):
         return '%s(%s)' % (self.__class__.__name__, self.service_name)
 
 
-
 class OperationModel(object):
     def __init__(self, operation_model, service_model, name=None):
         """
@@ -522,9 +523,11 @@ class OperationModel(object):
         if not input_shape:
             return []
 
-        return [name for (name, shape) in input_shape.members.items()
-                if 'idempotencyToken' in shape.metadata and
-                shape.metadata['idempotencyToken']]
+        return [
+            name for (name, shape) in input_shape.members.items()
+            if 'idempotencyToken' in shape.metadata
+            and shape.metadata['idempotencyToken']
+        ]
 
     @CachedProperty
     def auth_type(self):
@@ -543,6 +546,10 @@ class OperationModel(object):
     def http_checksum_required(self):
         return self._operation_model.get('httpChecksumRequired', False)
 
+    @CachedProperty
+    def http_checksum(self):
+        return self._operation_model.get('httpChecksum', {})
+
     @CachedProperty
     def has_event_stream_input(self):
         return self.get_event_stream_input() is not None
