@@ -266,6 +266,11 @@ class MaxAttemptsChecker(BaseRetryableChecker):
 
     def is_retryable(self, context):
         under_max_attempts = context.attempt_number < self._max_attempts
+        retries_context = context.request_context.get('retries')
+        if retries_context:
+            retries_context['max'] = max(
+                retries_context.get('max', 0), self._max_attempts
+            )
         if not under_max_attempts:
             logger.debug("Max attempts of %s reached.", self._max_attempts)
             context.add_retry_metadata(MaxAttemptsReached=True)
@@ -382,8 +387,7 @@ class ModeledRetryErrorDetector(object):
                 # Check if this error code matches the shape.  This can
                 # be either by name or by a modeled error code.
                 error_code_to_check = (
-                    shape.metadata.get('error', {}).get('code')
-                    or shape.name
+                    shape.metadata.get('error', {}).get('code') or shape.name
                 )
                 if error_code == error_code_to_check:
                     if shape.metadata['retryable'].get('throttling'):
@@ -430,8 +434,10 @@ class StandardRetryConditions(BaseRetryableChecker):
         ])
 
     def is_retryable(self, context):
-        return (self._max_attempts_checker.is_retryable(context) and
-                self._additional_checkers.is_retryable(context))
+        return (
+            self._max_attempts_checker.is_retryable(context)
+            and self._additional_checkers.is_retryable(context)
+        )
 
 
 class OrRetryChecker(BaseRetryableChecker):
