@@ -1,7 +1,3 @@
-from contextlib import contextmanager
-
-import mock
-
 from tests import BaseSessionTest, ClientHTTPStubber
 from ibm_botocore.history import BaseHistoryHandler
 from ibm_botocore.history import get_global_history_recorder
@@ -57,9 +53,9 @@ class TestRecordStatementsInjections(BaseSessionTest):
         event = api_call_events[0]
         event_type, payload, source = event
         self.assertEqual(payload, {
-                'operation': u'ListBuckets',
-                'params': {},
-                'service': 's3'
+            'operation': u'ListBuckets',
+            'params': {},
+            'service': 's3'
         })
         self.assertEqual(source, 'BOTOCORE')
 
@@ -104,7 +100,9 @@ class TestRecordStatementsInjections(BaseSessionTest):
         event = http_response_events[0]
         event_type, payload, source = event
 
-        self.assertEqual(payload, {
+        self.assertEqual(
+            payload,
+            {
                 'status_code': 200,
                 'headers': {},
                 'streaming': False,
