@@ -12,9 +12,10 @@
 # language governing permissions and limitations under the License.
 from tests import unittest, RawResponse
 import datetime
+import itertools
 
 from dateutil.tz import tzutc
-from nose.tools import assert_equal
+import pytest
 
 from ibm_botocore import parsers
 from ibm_botocore import model
@@ -376,6 +377,25 @@ class TestResponseMetadataParsed(unittest.TestCase):
         }
         self.assertEqual(parsed, expected)
 
+    # IBM Unsupported
+    # def test_checksum_metadata_parsed_from_response_context(self):
+    #     headers = {}
+    #     response_dict = {
+    #         'status_code': 200,
+    #         'headers': headers,
+    #         'body': b'',
+    #         'context': {
+    #             'checksum': {
+    #                 'response_algorithm': 'crc32'
+    #             }
+    #         }
+    #     }
+    #     parser = parsers.RestXMLParser()
+    #     parsed = parser.parse(response_dict, None)
+    #     expected_algorithm = 'crc32'
+    #     actual_algorithm = parsed['ResponseMetadata']['ChecksumAlgorithm']
+    #     self.assertEqual(actual_algorithm, expected_algorithm)
+
 
 class TestTaggedUnions(unittest.TestCase):
     def assert_tagged_union_response_with_unknown_member(self,
@@ -392,7 +412,7 @@ class TestTaggedUnions(unittest.TestCase):
                            'unknown to client'),
                           captured_log.records[0].getMessage())
 
-    def test_base_json_parser_handles_unknwon_member(self):
+    def test_base_json_parser_handles_unknown_member(self):
         parser = parsers.JSONParser()
         response = b'{"Foo": "mystring"}'
         headers = {'x-amzn-requestid': 'request-id'}
@@ -400,7 +420,7 @@ class TestTaggedUnions(unittest.TestCase):
             'OutputShape',
             {
                 'type': 'structure',
-                'union':True,
+                'union': True,
                 'members': {
                     'Str': {
                         'shape': 'StringType',
@@ -442,7 +462,7 @@ class TestTaggedUnions(unittest.TestCase):
             'OutputShape',
             {
                 'type': 'structure',
-                'union':True,
+                'union': True,
                 'resultWrapper': 'OperationNameResult',
                 'members': {
                     'Str': {
@@ -463,7 +483,7 @@ class TestTaggedUnions(unittest.TestCase):
             'SDK_UNKNOWN_MEMBER': {
                 'name': 'Foo'
             },
-            'ResponseMetadata':{
+            'ResponseMetadata': {
                 'RequestId': 'request-id',
                 'HTTPStatusCode': 200,
                 'HTTPHeaders': {}
@@ -483,7 +503,7 @@ class TestTaggedUnions(unittest.TestCase):
             'OutputShape',
             {
                 'type': 'structure',
-                'union':True,
+                'union': True,
                 'members': {
                     'Foo': {
                         'shape': 'StringType',
@@ -1267,7 +1287,7 @@ class TestParseErrorResponses(unittest.TestCase):
         body = (b'{"code":"AccessDeniedException","type":"Client","message":'
                 b'"Access denied"}')
         headers = {
-             'x-amzn-requestid': 'request-id'
+            'x-amzn-requestid': 'request-id'
         }
         parser = parsers.RestJSONParser()
         parsed = parser.parse(
@@ -1284,7 +1304,7 @@ class TestParseErrorResponses(unittest.TestCase):
             "message": "blah",
             "deletes": 0}'''
         headers = {
-             'x-amzn-requestid': 'request-id'
+            'x-amzn-requestid': 'request-id'
         }
         parser = parsers.RestJSONParser()
         parsed = parser.parse(
@@ -1296,7 +1316,7 @@ class TestParseErrorResponses(unittest.TestCase):
         body = (b'{"Code":"AccessDeniedException","type":"Client","Message":'
                 b'"Access denied"}')
         headers = {
-             'x-amzn-requestid': 'request-id'
+            'x-amzn-requestid': 'request-id'
         }
         parser = parsers.RestJSONParser()
         parsed = parser.parse(
@@ -1406,7 +1426,7 @@ class TestParseErrorResponses(unittest.TestCase):
         # We should be able to handle this gracefully and still at least
         # populate a "Message" key so that consumers don't have to
         # conditionally check for this.
-        body =  (
+        body = (
             '<ErrorResponse>'
             '  <Error>'
             '    <Type>Sender</Type>'
@@ -1425,26 +1445,28 @@ class TestParseErrorResponses(unittest.TestCase):
         self.assertEqual(error['Message'], '')
 
 
-def test_can_handle_generic_error_message():
-    # There are times when you can get a service to respond with a generic
-    # html error page.  We should be able to handle this case.
-    for parser_cls in parsers.PROTOCOL_PARSERS.values():
-        generic_html_body =  (
-            '<html><body><b>Http/1.1 Service Unavailable</b></body></html>'
-        ).encode('utf-8')
-        empty_body = b''
-        none_body = None
-        yield _assert_parses_generic_error, parser_cls(), generic_html_body
-        yield _assert_parses_generic_error, parser_cls(), empty_body
-        yield _assert_parses_generic_error, parser_cls(), none_body
+def _generic_test_bodies():
+    generic_html_body = (
+        '<html><body><b>Http/1.1 Service Unavailable</b></body></html>'
+    ).encode('utf-8')
+    empty_body = b''
+    none_body = None
+
+    return [generic_html_body, empty_body, none_body]
 
 
-def _assert_parses_generic_error(parser, body):
+@pytest.mark.parametrize(
+    "parser, body",
+    itertools.product(
+        parsers.PROTOCOL_PARSERS.values(),
+        _generic_test_bodies()
+    ),
+)
+def test_can_handle_generic_error_message(parser, body):
     # There are times when you can get a service to respond with a generic
     # html error page.  We should be able to handle this case.
-    parsed = parser.parse({
-        'body': body, 'headers': {}, 'status_code': 503}, None)
-    assert_equal(
-        parsed['Error'],
-        {'Code': '503', 'Message': 'Service Unavailable'})
-    assert_equal(parsed['ResponseMetadata']['HTTPStatusCode'], 503)
+    parsed = parser().parse(
+        {'body': body, 'headers': {}, 'status_code': 503}, None
+    )
+    assert parsed['Error'] == {'Code': '503', 'Message': 'Service Unavailable'}
+    assert parsed['ResponseMetadata']['HTTPStatusCode'] == 503
