@@ -16,8 +16,8 @@
 This is a test runner for all the JSON tests defined in
 ``tests/unit/protocols/``, including both the input/output tests.
 
-You can use the normal ``nosetests tests/unit/test_protocols.py`` to run
-this test.  In addition, there are several env vars you can use during
+You can use the normal ``python -m pytest tests/unit/test_protocols.py``
+to run this test.  In addition, there are several env vars you can use during
 development.
 
 Tests are broken down by filename, test suite, testcase.  When a test fails
@@ -37,40 +37,44 @@ failed test.
 To run tests from only a single file, you can set the
 BOTOCORE_TEST env var::
 
-    BOTOCORE_TEST=tests/unit/compliance/input/json.json nosetests tests/unit/test_protocols.py
+    BOTOCORE_TEST=tests/unit/compliance/input/json.json pytest tests/unit/test_protocols.py
 
 To run a single test suite you can set the BOTOCORE_TEST_ID env var:
 
     BOTOCORE_TEST=tests/unit/compliance/input/json.json BOTOCORE_TEST_ID=5 \
-        nosetests tests/unit/test_protocols.py
+        pytest tests/unit/test_protocols.py
 
 To run a single test case in a suite (useful when debugging a single test), you
 can set the BOTOCORE_TEST_ID env var with the ``suite_id:test_id`` syntax.
 
-    BOTOCORE_TEST_ID=5:1 nosetests test/unit/test_protocols.py
+    BOTOCORE_TEST_ID=5:1 pytest test/unit/test_protocols.py
 
 """
 import os
 import copy
+from enum import Enum
 
 from base64 import b64decode
 from dateutil.tz import tzutc
 
+import pytest
+
 from ibm_botocore.awsrequest import HeadersDict
 from ibm_botocore.compat import json, OrderedDict, urlsplit
 from ibm_botocore.eventstream import EventStream
 from ibm_botocore.model import ServiceModel, OperationModel
-from ibm_botocore.serialize import EC2Serializer, QuerySerializer, \
-        JSONSerializer, RestJSONSerializer, RestXMLSerializer
-from ibm_botocore.parsers import QueryParser, JSONParser, \
-        RestJSONParser, RestXMLParser, EC2QueryParser
+from ibm_botocore.serialize import (
+    EC2Serializer, QuerySerializer, JSONSerializer, RestJSONSerializer,
+    RestXMLSerializer,
+)
+from ibm_botocore.parsers import (
+    QueryParser, JSONParser, RestJSONParser, RestXMLParser, EC2QueryParser,
+)
 from ibm_botocore.utils import parse_timestamp, percent_encode_sequence
 from ibm_botocore.awsrequest import prepare_request_dict
 from calendar import timegm
 from ibm_botocore.model import NoShapeFoundError
 
-from nose.tools import assert_equal as _assert_equal
-
 TEST_DIR = os.path.join(
     os.path.dirname(os.path.abspath(__file__)),
     'protocols')
@@ -94,19 +98,34 @@ PROTOCOL_TEST_BLACKLIST = [
 ]
 
 
-def test_compliance():
+class TestType(Enum):
+    # Tell test runner to ignore this class
+    __test__ = False
+
+    INPUT = "input"
+    OUTPUT = "output"
+
+
+def _compliance_tests(test_type=None):
+    inp = test_type is None or test_type is TestType.INPUT
+    out = test_type is None or test_type is TestType.OUTPUT
+
     for full_path in _walk_files():
         if full_path.endswith('.json'):
             for model, case, basename in _load_cases(full_path):
                 if model.get('description') in PROTOCOL_TEST_BLACKLIST:
                     continue
-                if 'params' in case:
-                    yield _test_input, model, case, basename
-                elif 'response' in case:
-                    yield _test_output, model, case, basename
+                if 'params' in case and inp:
+                    yield model, case, basename
+                elif 'response' in case and out:
+                    yield model, case, basename
 
 
-def _test_input(json_description, case, basename):
+@pytest.mark.parametrize(
+    "json_description, case, basename",
+    _compliance_tests(TestType.INPUT)
+)
+def test_input_compliance(json_description, case, basename):
     service_description = copy.deepcopy(json_description)
     service_description['operations'] = {
         case.get('name', 'OperationName'): case,
@@ -153,7 +172,11 @@ class MockRawResponse(object):
         yield self._data
 
 
-def _test_output(json_description, case, basename):
+@pytest.mark.parametrize(
+    "json_description, case, basename",
+    _compliance_tests(TestType.OUTPUT)
+)
+def test_output_compliance(json_description, case, basename):
     service_description = copy.deepcopy(json_description)
     operation_name = case.get('name', 'OperationName')
     service_description['operations'] = {
@@ -322,7 +345,7 @@ def assert_equal(first, second, prefix):
     # A better assert equals.  It allows you to just provide
     # prefix instead of the entire message.
     try:
-        _assert_equal(first, second)
+        assert first == second
     except Exception:
         try:
             better = "%s (actual != expected)\n%s !=\n%s" % (
@@ -355,14 +378,25 @@ def _serialize_request_description(request_dict):
 def _assert_requests_equal(actual, expected):
     assert_equal(actual['body'], expected.get('body', '').encode('utf-8'),
                  'Body value')
-    actual_headers = dict(actual['headers'])
-    expected_headers = expected.get('headers', {})
-    assert_equal(actual_headers, expected_headers, "Header values")
+    actual_headers = HeadersDict(actual['headers'])
+    expected_headers = HeadersDict(expected.get('headers', {}))
+    excluded_headers = expected.get('forbidHeaders', [])
+    _assert_expected_headers_in_request(
+        actual_headers, expected_headers, excluded_headers
+    )
     assert_equal(actual['url_path'], expected.get('uri', ''), "URI")
     if 'method' in expected:
         assert_equal(actual['method'], expected['method'], "Method")
 
 
+def _assert_expected_headers_in_request(actual, expected, excluded_headers):
+    for header, value in expected.items():
+        assert header in actual
+        assert actual[header] == value
+    for header in excluded_headers:
+        assert header not in actual
+
+
 def _walk_files():
     # Check for a shortcut when running the tests interactively.
     # If a BOTOCORE_TEST env var is defined, that file is used as the
