@@ -13,13 +13,14 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 import ibm_botocore.config
-from tests import unittest, create_session, temporary_file, requires_crt
+from tests import mock, unittest, create_session, temporary_file, requires_crt
 import os
 import logging
 import tempfile
 import shutil
 
-import mock
+import pytest
+
 
 import ibm_botocore.session
 import ibm_botocore.exceptions
@@ -307,7 +308,7 @@ class TestBuiltinEventHandlers(BaseSessionTest):
         self.foo_called = True
 
     def tearDown(self):
-        super(TestBuiltinEventHandlers, self).setUp()
+        super(TestBuiltinEventHandlers, self).tearDown()
         self.handler_patch.stop()
 
     def test_registered_builtin_handlers(self):
@@ -379,6 +380,22 @@ class TestSessionPartitionFiles(BaseSessionTest):
         regions = self.session.get_available_regions('__foo__')
         self.assertEqual([], regions)
 
+    def test_provides_correct_partition_for_region(self):
+        partition = self.session.get_partition_for_region('us-west-2')
+        self.assertEqual(partition, 'aws')
+
+    def test_provides_correct_partition_for_region_regex(self):
+        partition = self.session.get_partition_for_region('af-south-99')
+        self.assertEqual(partition, 'aws')
+
+    def test_provides_correct_partition_for_region_non_default(self):
+        partition = self.session.get_partition_for_region('cn-north-1')
+        self.assertEqual(partition, 'aws-cn')
+
+    def test_raises_exception_for_invalid_region(self):
+        with self.assertRaises(ibm_botocore.exceptions.UnknownRegionError):
+            self.session.get_partition_for_region('no-good-1')
+
 
 class TestSessionUserAgent(BaseSessionTest):
     def test_can_change_user_agent_name(self):
@@ -675,10 +692,10 @@ class TestCreateClient(BaseSessionTest):
             del self.environ['FOO_PROFILE']
             self.environ['FOO_CONFIG_FILE'] = f.name
             f.write('[default]\n')
-            f.write('foo_api_versions =\n'
-                    '    myservice = %s\n'
-                    '    myservice2 = %s\n' % (
-                        config_api_version, second_config_api_version)
+            f.write(
+                f'foo_api_versions =\n'
+                f'    myservice = {config_api_version}\n'
+                f'    myservice2 = {second_config_api_version}\n'
             )
             f.flush()
 
@@ -711,6 +728,33 @@ class TestCreateClient(BaseSessionTest):
                 create_client.call_args[1]
             self.assertEqual(call_kwargs['api_version'], override_api_version)
 
+    @mock.patch('ibm_botocore.client.ClientCreator')
+    def test_defaults_mode_resolved_from_config_store(self, client_creator):
+        config_store = self.session.get_component('config_store')
+        config_store.set_config_variable('defaults_mode', 'standard')
+        self.session.create_client('sts', 'us-west-2')
+        self.assertIsNot(client_creator.call_args[0][-1], config_store)
+
+    @mock.patch('ibm_botocore.client.ClientCreator')
+    def test_defaults_mode_resolved_from_client_config(self, client_creator):
+        config_store = self.session.get_component('config_store')
+        config = ibm_botocore.config.Config(defaults_mode='standard')
+        self.session.create_client('sts', 'us-west-2', config=config)
+        self.assertIsNot(client_creator.call_args[0][-1], config_store)
+
+    @mock.patch('ibm_botocore.client.ClientCreator')
+    def test_defaults_mode_resolved_invalid_mode_exception(self,
+                                                           client_creator):
+        with self.assertRaises(ibm_botocore.exceptions.InvalidDefaultsMode):
+            config = ibm_botocore.config.Config(defaults_mode='foo')
+            self.session.create_client('sts', 'us-west-2', config=config)
+
+    @mock.patch('ibm_botocore.client.ClientCreator')
+    def test_defaults_mode_resolved_legacy(self, client_creator):
+        config_store = self.session.get_component('config_store')
+        self.session.create_client('sts', 'us-west-2')
+        self.assertIs(client_creator.call_args[0][-1], config_store)
+
 
 class TestSessionComponent(BaseSessionTest):
     def test_internal_component(self):
@@ -719,21 +763,29 @@ class TestSessionComponent(BaseSessionTest):
         self.assertIs(
             self.session._get_internal_component('internal'), component)
         with self.assertRaises(ValueError):
-            self.session.get_component('internal')
+            # get_component has been deprecated to the public
+            with pytest.warns(DeprecationWarning):
+                self.session.get_component('internal')
 
     def test_internal_endpoint_resolver_is_same_as_deprecated_public(self):
         endpoint_resolver = self.session._get_internal_component(
             'endpoint_resolver')
-        self.assertIs(
-            self.session.get_component('endpoint_resolver'), endpoint_resolver)
+        # get_component has been deprecated to the public
+        with pytest.warns(DeprecationWarning):
+            self.assertIs(
+                self.session.get_component('endpoint_resolver'),
+                endpoint_resolver
+            )
 
     def test_internal_exceptions_factory_is_same_as_deprecated_public(self):
         exceptions_factory = self.session._get_internal_component(
             'exceptions_factory')
-        self.assertIs(
-            self.session.get_component('exceptions_factory'),
-            exceptions_factory
-        )
+        # get_component has been deprecated to the public
+        with pytest.warns(DeprecationWarning):
+            self.assertIs(
+                self.session.get_component('exceptions_factory'),
+                exceptions_factory
+            )
 
 
 class TestClientMonitoring(BaseSessionTest):
@@ -745,9 +797,10 @@ class TestClientMonitoring(BaseSessionTest):
             client.meta.events)
 
     def assert_monitoring_host_and_port(self, session, host, port):
-        with mock.patch('ibm_botocore.monitoring.SocketPublisher',
-                        spec=True) as mock_publisher:
-            client = session.create_client('s3', 'us-west-2')
+        with mock.patch(
+            'ibm_botocore.monitoring.SocketPublisher', spec=True
+        ) as mock_publisher:
+            session.create_client('s3', 'us-west-2')
         self.assertEqual(mock_publisher.call_count, 1)
         _, args, kwargs = mock_publisher.mock_calls[0]
         self.assertEqual(kwargs.get('host'), host)
@@ -888,7 +941,7 @@ class TestSessionRegionSetup(BaseSessionTest):
 
     def test_new_session_with_invalid_region(self):
         with self.assertRaises(ibm_botocore.exceptions.InvalidRegionError):
-            s3_client = self.session.create_client('s3', 'not.a.real#region')
+            self.session.create_client('s3', 'not.a.real#region')
 
     def test_new_session_with_none_region(self):
         s3_client = self.session.create_client('s3', region_name=None)
