@@ -11,9 +11,7 @@
 # ANY KIND, either express or implied. See the License for the specific
 # language governing permissions and limitations under the License.
 import os
-from tests import unittest, BaseEnvVar
-
-import mock
+from tests import mock, unittest, BaseEnvVar
 
 import ibm_botocore
 from ibm_botocore.compat import six
@@ -422,37 +420,64 @@ class TestWaitersObjects(unittest.TestCase):
 
     def test_waiter_failure_state_error(self):
         test_cases = [
-            ([{'state': 'failure', 'matcher': 'path',
-               'argument': 'Foo', 'expected': 'FAILURE'}],
-             [{'Foo': 'FAILURE'}],
-             'FAILURE'),
-            ([{'state': 'failure', 'matcher': 'pathAll',
-               'argument': 'Tables[].State', 'expected': 'FAILURE'}],
-             [{'Tables': [{"State": "FAILURE"}]}],
-             'FAILURE'),
-            ([{'state': 'failure', 'matcher': 'pathAny',
-               'argument': 'Tables[].State', 'expected': 'FAILURE'}],
-             [{'Tables': [{"State": "FAILURE"}]}],
-             'FAILURE'),
-            ([{'state': 'failure', 'matcher': 'status', 'expected': 404}],
-             [{'ResponseMetadata': {'HTTPStatusCode': 404}}],
-             '404'),
-            ([{'state': 'failure', 'matcher': 'error', 'expected': 'FailError'}],
-             [{'Error': {'Code': 'FailError', 'Message': 'foo'}}],
-             'FailError'),
-            ([{'state': 'retry', 'matcher': 'error', 'expected': 'RetryMe'}],
-             [{'Success': False}]*4,
-             'Max attempts exceeded'),
-            ([
-                {'state': 'success', 'matcher': 'status', 'expected': 200},
-                {'state': 'retry', 'matcher': 'error', 'expected': 'RetryMe'},
-            ],
-             [{'Success': False},
-              {'Error': {'Code': 'RetryMe', 'Message': 'foo'}},
-              {'Success': False},
-              {'Success': False},
-              ],
-             'Previously accepted state'),
+            (
+                [
+                    {
+                        'state': 'failure', 'matcher': 'path',
+                        'argument': 'Foo', 'expected': 'FAILURE'
+                    }
+                ],
+                [{'Foo': 'FAILURE'}],
+                'FAILURE'
+            ),
+            (
+                [
+                    {
+                        'state': 'failure', 'matcher': 'pathAll',
+                        'argument': 'Tables[].State', 'expected': 'FAILURE'
+                    }
+                ],
+                [{'Tables': [{"State": "FAILURE"}]}],
+                'FAILURE'
+            ),
+            (
+                [
+                    {
+                        'state': 'failure', 'matcher': 'pathAny',
+                        'argument': 'Tables[].State', 'expected': 'FAILURE'
+                    }
+                ],
+                [{'Tables': [{"State": "FAILURE"}]}],
+                'FAILURE'
+            ),
+            (
+                [{'state': 'failure', 'matcher': 'status', 'expected': 404}],
+                [{'ResponseMetadata': {'HTTPStatusCode': 404}}],
+                '404'
+            ),
+            (
+                [{'state': 'failure', 'matcher': 'error', 'expected': 'FailError'}],
+                [{'Error': {'Code': 'FailError', 'Message': 'foo'}}],
+                'FailError'
+            ),
+            (
+                [{'state': 'retry', 'matcher': 'error', 'expected': 'RetryMe'}],
+                [{'Success': False}]*4,
+                'Max attempts exceeded'
+            ),
+            (
+                [
+                    {'state': 'success', 'matcher': 'status', 'expected': 200},
+                    {'state': 'retry', 'matcher': 'error', 'expected': 'RetryMe'},
+                ],
+                [
+                    {'Success': False},
+                    {'Error': {'Code': 'RetryMe', 'Message': 'foo'}},
+                    {'Success': False},
+                    {'Success': False},
+                ],
+                'Previously accepted state'
+            ),
         ]
 
         for acceptors, responses, expected_msg in test_cases:
